# Changelog

## [0.2.0](https://github.com/bdesanctis/bamdam/compare/v0.1.2...v0.2.0) (2025-06-11)


### Miscellaneous Chores

* release 0.2.0 ([1b20f30](https://github.com/bdesanctis/bamdam/commit/1b20f30f0d7c29bd4ba085851d96cbd9b7110897))

## [0.1.2](https://github.com/bdesanctis/bamdam/compare/v0.1.1...v0.1.2) (2025-06-03)


### Bug Fixes

* added GC content and more averaging to the combine function, fixed ^Ms at ends of tsv file lines, added an empty lca error catch ([00c492c](https://github.com/bdesanctis/bamdam/commit/00c492c844d3aa78e5f7552ab28334b03c9adc9d))


### Documentation

* update install, add workflow img ([f231807](https://github.com/bdesanctis/bamdam/commit/f231807ffedd807d1e4e619a21ef6843b14c3d93))

## [0.1.1](https://github.com/bdesanctis/bamdam/compare/v0.1.0...v0.1.1) (2025-04-07)


### Bug Fixes

* rename release workflow file ([f7790e5](https://github.com/bdesanctis/bamdam/commit/f7790e565bba3940f6fc3d6834685bf4b87a3273))

## 0.1.0 (2025-04-07)


### Miscellaneous Chores

* release 0.1.0 ([f21226a](https://github.com/bdesanctis/bamdam/commit/f21226a36e5aa53ac349a701994ab2002f64abd8))
